@@ -13,17 +13,15 @@
 #include <QStatusBar>
 
 // KF
-#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KToggleAction>
 
 // KDEGames
-#include <kdegames_version.h>
+#include <KGameThemeSelector>
 #include <KScoreDialog>
-#include <KStandardGameAction>
-#include <KgThemeSelector>
+#include <KGameStandardAction>
 
 // Bomber
 #include "settings.h"
@@ -31,13 +29,10 @@
 Bomber::Bomber()
 {
     m_provider.discoverThemes(
-#if KDEGAMES_VERSION < QT_VERSION_CHECK(7, 4, 0)
-        "appdata",
-#endif
         QStringLiteral("themes"),   //theme data location
         QStringLiteral("kbomber")); //default theme name
 
-    m_selector = new KgThemeSelector(&m_provider);
+    m_selector = new KGameThemeSelector(&m_provider);
 
     m_statusBar = statusBar();
     m_level = new QLabel(i18nc("Used to display the current level of play to the user", "Level: %1", 0));
@@ -48,7 +43,7 @@ Bomber::Bomber()
     m_statusBar->addPermanentWidget(m_lives);
 
     m_gameWidget = new BomberGameWidget(&m_provider, this);
-    connect(&m_provider, &KgThemeProvider::currentThemeChanged, m_gameWidget, &BomberGameWidget::settingsChanged);
+    connect(&m_provider, &KGameThemeProvider::currentThemeChanged, m_gameWidget, &BomberGameWidget::settingsChanged);
 
     connect(m_gameWidget, &BomberGameWidget::levelChanged, this, &Bomber::displayLevel);
     connect(m_gameWidget, &BomberGameWidget::scoreChanged, this, &Bomber::displayScore);
@@ -76,11 +71,11 @@ Bomber::~Bomber()
 void Bomber::initXMLUI()
 {
     // Game
-    m_newAction = KStandardGameAction::gameNew(this, &Bomber::newGame, actionCollection());
-    KStandardGameAction::end(this, &Bomber::closeGame, actionCollection());
-    m_pauseAction = KStandardGameAction::pause(this, &Bomber::pauseGame, actionCollection());
-    KStandardGameAction::highscores(this, &Bomber::showHighscore, actionCollection());
-    KStandardGameAction::quit(this, &QWidget::close, actionCollection());
+    m_newAction = KGameStandardAction::gameNew(this, &Bomber::newGame, actionCollection());
+    KGameStandardAction::end(this, &Bomber::closeGame, actionCollection());
+    m_pauseAction = KGameStandardAction::pause(this, &Bomber::pauseGame, actionCollection());
+    KGameStandardAction::highscores(this, &Bomber::showHighscore, actionCollection());
+    KGameStandardAction::quit(this, &QWidget::close, actionCollection());
 
     // Settings
     KStandardAction::preferences(this, &Bomber::showPreferences, actionCollection());
@@ -93,7 +88,7 @@ void Bomber::initXMLUI()
     dropBombAction->setToolTip(i18nc("The tool tip text for the action used to drop bombs", "Drop bomb"));
     dropBombAction->setWhatsThis(i18nc("Description of the action used to drop bombs",
                                        "Makes the plane drop a bomb while flying"));
-    actionCollection()->setDefaultShortcut(dropBombAction, Qt::Key_Space);
+    KActionCollection::setDefaultShortcut(dropBombAction, Qt::Key_Space);
     dropBombAction->setEnabled(true);
     connect(dropBombAction, &QAction::triggered, m_gameWidget, &BomberGameWidget::onDropBomb);
 }
@@ -134,20 +129,12 @@ void Bomber::closeGame()
     if (old_state == BomberGameWidget::State::Running) {
         m_gameWidget->setPaused(true);
     }
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     int ret = KMessageBox::questionTwoActions(this,
-#else
-    int ret = KMessageBox::questionYesNo(this,
-#endif
                                          i18nc("Message displayed when player tries to quit a game that is currently running",
                                                "Do you really want to close the running game?"),
                                          QString(),
                                          KStandardGuiItem::close(), KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (ret == KMessageBox::PrimaryAction) {
-#else
-    if (ret == KMessageBox::Yes) {
-#endif
         m_gameWidget->closeGame();
     } else if (old_state == BomberGameWidget::State::Running) {
         m_gameWidget->setPaused(false);
